==> kubernetes-model-node-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/node/v1alpha1/OverheadFluentImpl.java <==
package io.fabric8.kubernetes.api.model.node.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OverheadFluentImpl<A extends OverheadFluent<A>> extends BaseFluent<A> implements OverheadFluent<A>{
  public OverheadFluentImpl() {
  }
  public OverheadFluentImpl(Overhead instance) {
    this.withPodFixed(instance.getPodFixed()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Map<String,Quantity> podFixed;
  private Map<String,Object> additionalProperties;
  public A addToPodFixed(String key,Quantity value) {
    if(this.podFixed == null && key != null && value != null) { this.podFixed = new LinkedHashMap(); }
    if(key != null && value != null) {this.podFixed.put(key, value);} return (A)this;
  }
  public A addToPodFixed(Map<String,Quantity> map) {
    if(this.podFixed == null && map != null) { this.podFixed = new LinkedHashMap(); }
    if(map != null) { this.podFixed.putAll(map);} return (A)this;
  }
  public A removeFromPodFixed(String key) {
    if(this.podFixed == null) { return (A) this; }
    if(key != null && this.podFixed != null) {this.podFixed.remove(key);} return (A)this;
  }
  public A removeFromPodFixed(Map<String,Quantity> map) {
    if(this.podFixed == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.podFixed != null){this.podFixed.remove(key);}}} return (A)this;
  }
  public Map<String,Quantity> getPodFixed() {
    return this.podFixed;
  }
  public <K,V>A withPodFixed(Map<String,Quantity> podFixed) {
    if (podFixed == null) { this.podFixed =  null;} else {this.podFixed = new LinkedHashMap(podFixed);} return (A) this;
  }
  public Boolean hasPodFixed() {
    return this.podFixed != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OverheadFluentImpl that = (OverheadFluentImpl) o;
    if (podFixed != null ? !podFixed.equals(that.podFixed) :that.podFixed != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(podFixed,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (podFixed != null && !podFixed.isEmpty()) { sb.append("podFixed:"); sb.append(podFixed + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> kubernetes-model-node-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/node/v1alpha1/OverheadFluentImpl.java <==
package io.fabric8.kubernetes.api.model.node.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OverheadFluentImpl<A extends OverheadFluent<A>> extends BaseFluent<A> implements OverheadFluent<A>{
  public OverheadFluentImpl() {
  }
  public OverheadFluentImpl(Overhead instance) {
    if (instance != null) {
      this.withPodFixed(instance.getPodFixed());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Map<String,Quantity> podFixed;
  private Map<String,Object> additionalProperties;
  public A addToPodFixed(String key,Quantity value) {
    if(this.podFixed == null && key != null && value != null) { this.podFixed = new LinkedHashMap(); }
    if(key != null && value != null) {this.podFixed.put(key, value);} return (A)this;
  }
  public A addToPodFixed(Map<String,Quantity> map) {
    if(this.podFixed == null && map != null) { this.podFixed = new LinkedHashMap(); }
    if(map != null) { this.podFixed.putAll(map);} return (A)this;
  }
  public A removeFromPodFixed(String key) {
    if(this.podFixed == null) { return (A) this; }
    if(key != null && this.podFixed != null) {this.podFixed.remove(key);} return (A)this;
  }
  public A removeFromPodFixed(Map<String,Quantity> map) {
    if(this.podFixed == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.podFixed != null){this.podFixed.remove(key);}}} return (A)this;
  }
  public Map<String,Quantity> getPodFixed() {
    return this.podFixed;
  }
  public <K,V>A withPodFixed(Map<String,Quantity> podFixed) {
    if (podFixed == null) { this.podFixed =  null;} else {this.podFixed = new LinkedHashMap(podFixed);} return (A) this;
  }
  public Boolean hasPodFixed() {
    return this.podFixed != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OverheadFluentImpl that = (OverheadFluentImpl) o;
    if (!java.util.Objects.equals(podFixed, that.podFixed)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(podFixed,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (podFixed != null && !podFixed.isEmpty()) { sb.append("podFixed:"); sb.append(podFixed + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
